.. include:: ../common/unsafe.rst

Random Numbers
================

This module is imported with::

    import toy_crypto.rand

.. currentmodule:: toy_crypto.rand

For the most part, the functions here duplicate some utilities from :py:mod:`random`, but use the cryptographically secure random number generator from :py:mod:`secrets`.


The :mod:`rand` functions
--------------------------

.. automodule:: toy_crypto.rand
    :synopsis: Randon number utitilities
    :members:
